"use strict";
/*!--------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See LICENSE in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.RootCompletionCollection = void 0;
const vscode_languageserver_1 = require("vscode-languageserver");
const CompletionCollection_1 = require("./CompletionCollection");
/**
 * The position given when the cursor is at the root, i.e. at the | below:
|
services:
  foo:
    a: b
 */
const PositionAtRootPathRegex = /^\/$/i; // e.g. /
/**
 * The position given when the cursor is in a partially-typed root key, i.e. at the | below:
val|
services:
  foo:
    a: b
 */
const PositionInRootKeyPathRegex = /^\/<value>$/i; // e.g. /<value>
exports.RootCompletionCollection = new CompletionCollection_1.CompletionCollection('root', { logicalPaths: [PositionAtRootPathRegex, PositionInRootKeyPathRegex], indentationDepth: 0 }, ...[
    {
        label: 'configs:',
        insertText: 'configs:\n',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.PlainText,
        isAdvancedComposeCompletion: false,
    },
    {
        label: 'networks:',
        insertText: 'networks:\n',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.PlainText,
        isAdvancedComposeCompletion: false,
    },
    {
        label: 'secrets:',
        insertText: 'secrets:\n',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.PlainText,
        isAdvancedComposeCompletion: false,
    },
    {
        label: 'services:',
        insertText: 'services:\n',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.PlainText,
        isAdvancedComposeCompletion: false,
    },
    {
        label: 'version:',
        insertText: 'version: \'${1:version}\'$0',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.Snippet,
        isAdvancedComposeCompletion: false,
    },
    {
        label: 'volumes:',
        insertText: 'volumes:\n',
        insertTextFormat: vscode_languageserver_1.InsertTextFormat.PlainText,
        isAdvancedComposeCompletion: false,
    },
]);
//# sourceMappingURL=RootCompletionCollection.js.map